\name{carma}
\title{Continuous ARMA for Unequally Spaced Repeated Measurements}
\alias{carma}
\usage{
carma(response=NULL, ccov=NULL, times=NULL, torder=0, interaction,
	arma=c(0,0,0), parma=NULL, pre=NULL, position=NULL, iopt=TRUE,
	resid=TRUE, transform="identity", delta=NULL, envir=parent.frame(),
	print.level=0, typsiz=abs(p), ndigit=10, gradtol=0.00001,
	steptol=0.00001, iterlim=100, fscale=1, stepmax=10*sqrt(p%*%p))
fitted.carma(z, recursive=TRUE)
mprofile.carma(z, times=NULL, ccov, plotse=TRUE)
residuals.carma(z, recursive=TRUE)
}
\alias{fitted.carma}
\alias{mprofile.carma}
\alias{residuals.carma}
\description{
\code{carma} is designed to handle a polynomial within subject
design matrix with unequally spaced observations which can be at
different times for different subjects. The origin of time is taken
as the mean time of all the subjects. The within subject errors are
assumed to be independent Gaussian or have a continuous time ARMA(p,q)
Gaussian structure with the option to include measurement error.
The between subject random coefficients are assumed to have an
arbitrary covariance matrix. The fixed effect design matrix is a
polynomial of equal or higher order than the within subject design
matrix. This matrix can be augmented by covariates multiplied by
polynomial design matrices of any order up to the order of the first
partition of the design matrix. The method is based on exact maximum
likelihood using the Kalman filter to calculate the likelihood.

For clustered (non-longitudinal) data, where only random effects will
be fitted, \code{times} are not necessary.

Marginal and individual profiles can be plotted using
\code{\link[rmutil]{mprofile}} and \code{\link[rmutil]{iprofile}} and
residuals with \code{\link[rmutil]{plot.residuals}}.

For any ARMA of order superior to an AR(1), the (complex) roots of
the characteristic equation are printed out; see Jones and Ackerson
(1991) for their use in calculation of the covariance function.
}
\arguments{
\item{response}{A list of two column matrices with response values and
times for each individual, one matrix or dataframe of response
values, or an object of either class, \code{response} (created by
\code{\link[rmutil]{restovec}}) or \code{repeated} (created by
\code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{ccov}{A matrix of columns of baseline covariates with one row per
individual, a model formula using vectors of the same size, or an
object of class, \code{tccov} (created by \code{\link[rmutil]{tcctomat}}). If
response has class, \code{repeated}, the covariates must be specified as a
Wilkinson and Rogers formula unless none are to be used.}
\item{times}{When response is a matrix, a vector of possibly unequally
spaced times when they are the same for all individuals or a matrix of
times. Not necessary if equally spaced. Ignored if response has class,
\code{response} or \code{repeated}.}
\item{torder}{Order of the polynomial in time to be fitted.}
\item{interaction}{Vector indicating order of interactions of covariates
with time.}
\item{transform}{Transformation of the response variable: \code{identity},
\code{exp}, \code{square}, \code{sqrt}, or \code{log}.}
\item{arma}{Vector of three values: order of AR, order of MA, binary
indicator for presence of measurement error. Not required for an AR(1)
if an initial estimate is supplied. If only one value is supplied, it
is assumed to be the order of the AR.}
\item{parma}{Initial estimates of ARMA parameters. For example, with
\code{arma=c(1,0,0)}, an AR(1), the parameter is
\code{parma[1]=log(theta)}, where \code{theta} is the positive,
continuous time autoregressive coefficient. The finite step
autoregression coefficient for a step of length \code{delta} is then
\code{alpha=exp(-delta*theta)}
i.e. \code{alpha=exp(-delta*exp(parma[1]))}.}
\item{pre}{Initial estimates of random effect parameters.}
\item{position}{Two column matrix with rows giving index positions of
random effects in the covariance matrix.}
\item{iopt}{TRUE if optimization should be performed.}
\item{resid}{TRUE if residuals to be calculated.}
\item{delta}{Scalar or vector giving the unit of measurement
for each response value, set to unity by default. For example, if a
response is measured to two decimals, \code{delta=0.01}. Ignored if
response has class, \code{response} or \code{repeated}.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}.
If \code{response} has class \code{repeated}, it is used as the
environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
\item{z}{An object of class, \code{carma}.}
\item{plotse}{Plot the standard errors around the marginal profile
curve.}
\item{recursive}{If TRUE, recursive residuals or fitted values are
given; otherwise, marginal ones.}
}
\value{
A list of class \code{carma} is returned that contains all of the
relevant information calculated, including error codes.
}
\references{
Jones, R. H. and Ackerson, L. M. (1991) Serial correlation in
unequally spaced longitudinal data. Biometrika, 77, 721-731.

Jones, R.H. (1993) Longitudinal Data Analysis with Serial Correlation:
A State-space Approach. Chapman and Hall
}
\author{R.H. Jones and J.K. Lindsey}
\seealso{
\code{\link[growth]{elliptic}}, \code{\link[repeated]{gar}},
\code{\link[repeated]{gnlmix}}, \code{\link[repeated]{glmm}},
\code{\link[repeated]{gnlmm}}, \code{\link[rmutil]{iprofile}},
\code{\link[repeated]{kalseries}}, \code{\link[rmutil]{mprofile}},
\code{\link[rmutil]{plot.residuals}}, \code{\link[growth]{potthoff}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
y <- matrix(rnorm(40),ncol=5)
x1 <- gl(2,4)
x2 <- gl(2,1,8)
# independence with time trend
carma(y, ccov=~x1, torder=2)
# AR(1)
carma(y, ccov=~x1, torder=2, arma=c(1,0,0), parma=-0.5)
carma(y, ccov=~x1, torder=3, interact=3, arma=c(1,0,0), parma=-1)
# ARMA(2,1)
carma(y, ccov=~x1+x2, interact=c(2,0), torder=3,arma=c(2,1,0),
	parma=c(0.3,2,0.7))
# random intercept
carma(y, ccov=~x1+x2, interact=c(2,0), torder=3, pre=-0.4, 
	position=c(1,1))
# random coefficients
carma(y, ccov=~x1+x2, interact=c(2,0), torder=3, pre=c(-0.4,0.1), 
	position=rbind(c(1,1),c(2,2)))
}
\keyword{models}

\eof
\name{corgram}
\title{Calculate and Plot a Correlogram}
\alias{corgram}
\usage{
corgram(y, wt=1, maxlag=NULL, partial=FALSE, add=FALSE, lty=1, xlim=NULL,
	ylim=NULL, xlab=NULL, ylab=NULL, main=NULL, ...)
}
\description{
\code{corgram} calculates the values of a correlogram (autocorrelation
function or ACF) and plots it.
}
\arguments{
\item{y}{A time series vector.}
\item{maxlag}{Maximum number of lags for which the correlation is to
be calculated.}
\item{partial}{If TRUE, the partial autocorrelation function (PACF) is
plotted.}
\item{wt}{Indicator vector with zeros for values to be ignored.}
\item{add}{If TRUE, adds a new correlogram to an existing plot.}
\item{others}{Plotting parameters}
}
\value{
\code{corgram} returns a two-column matrix containing the (partial) correlogram
coordinates.
}
\author{J.K. Lindsey}
\examples{
y <- rnorm(100)
corgram(y)
corgram(y, partial=TRUE)
}
\keyword{hplot}

\eof
\name{elliptic}
\title{Nonlinear Multivariate Elliptically-contoured}
\alias{elliptic}
Repeated Measurements Models with AR(1) and Two Levels of
Variance Components}
\usage{
elliptic(response=NULL, model="linear", distribution="normal",
	times=NULL, dose=NULL, ccov=NULL, tvcov=NULL, nest=NULL,
	torder=0, interaction=NULL, transform="identity",
	link="identity", autocorr="exponential", pell=NULL, preg=NULL,
	pvar=var(y), varfn=NULL, par=NULL, pre=NULL, delta=NULL,
	shfn=FALSE, common=FALSE, envir=parent.frame(),
	print.level=0, ndigit=10, gradtol=0.00001, steptol=0.00001,
	iterlim=100, fscale=1, stepmax=10*sqrt(theta%*%theta),
	typsiz=abs(c(theta)))
fitted.elliptic(z, recursive=FALSE)
residuals.elliptic(z, recursive=FALSE)
}
\alias{fitted.elliptic}
\alias{residuals.elliptic}
\description{
\code{elliptic} fits special cases of the multivariate
elliptically-contoured distribution, the multivariate normal, Student
t, and power exponential distributions. The latter includes the
multivariate normal (power=1), a multivariate Laplace (power=0.5),
and the multivariate uniform (power -> infinity) distributions as
special cases. As well, another form of multivariate skew Laplace
distribution is also available.

With two levels of nesting, the first is the individual and the second
will consist of clusters within individuals.

For clustered (non-longitudinal) data, where only random effects will
be fitted, \code{times} are not necessary.

This function is designed to fit linear and nonlinear models with
time-varying covariates observed at arbitrary time points. A
continuous-time AR(1) and zero, one, or two levels of nesting can be
handled. Recall that zero correlation (all zeros off-diagonal in the
covariance matrix) only implies independence for the multivariate
normal distribution.

Nonlinear regression models can be supplied as formulae where
parameters are unknowns in which case factor variables cannot be used
and parameters must be scalars. (See \code{\link[rmutil]{finterp}}.)

Recursive fitted values and residuals are only available for the
multivariate normal distribution with a linear model without a variance
function and with either an AR(1) of \code{exponential} form and/or
one level of random effect. In these cases, marginal and individual
profiles can be plotted using \code{\link[rmutil]{mprofile}} and
\code{\link[rmutil]{iprofile}} and residuals with
\code{\link[rmutil]{plot.residuals}}.
}
\arguments{
\item{response}{A list of two or three column matrices with response
values, times, and possibly nesting categories, for each individual,
one matrix or dataframe of response values, or an object of class,
\code{response} (created by \code{\link[rmutil]{restovec}}) or \code{repeated}
(created by \code{\link[rmutil]{rmna}} or \code{\link[rmutil]{lvna}}). If the
\code{repeated} data object contains more than one response variable,
give that object in \code{envir} and give the name of the response
variable to be used here.}
\item{model}{The model to be fitted for the location. Builtin choices
are (1) \code{linear} for linear models with time-varying covariate; if
\code{torder > 0}, a polynomial in time is automatically fitted; (2)
\code{logistic} for a four-parameter logistic growth curve; (3)
\code{pkpd} for a first-order one-compartment pharmacokinetic model.
Otherwise, set this to a function of the parameters or a formula
beginning with ~, specifying either a linear regression function for
the location parameter in the Wilkinson and Rogers notation or a
general function with named unknown parameters that describes the
location, returning a vector the same length as the number of
observations, in which case \code{ccov} and \code{tvcov} cannot be used.}
\item{distribution}{Multivariate \code{normal}, \code{power
exponential}, \code{Student t}, or skew \code{Laplace}
distribution. The latter is not an elliptical distribution.
Note that the latter has a different parametrization of the skew
(family) parameter than the univariate skew Laplace distribution in
\code{\link[rmutil]{dskewlaplace}}:
\eqn{skew=\frac{\sigma(1-\nu^2)}{\sqrt{2}\nu}}{skew = (s * (1 - f^2))
/ (sqrt(2) * f)}. Here, zero skew yields a symmetric distribution.}
\item{times}{When \code{response} is a matrix, a vector of possibly
unequally spaced times when they are the same for all individuals or a
matrix of times. Not necessary if equally spaced. Ignored if response
has class, \code{response} or \code{repeated}.}
\item{dose}{A vector of dose levels for the \code{pkpd model}, one per
individual.}
\item{ccov}{A vector or matrix containing time-constant baseline
covariates with one line per individual, a model formula using
vectors of the same size, or an object of class, \code{tccov} (created by
\code{\link[rmutil]{tcctomat}}). If response has class, \code{repeated}, with a
\code{linear}, \code{logistic}, or \code{pkpd} model, the covariates
must be specified as a Wilkinson and Rogers formula unless none are
to be used. For the \code{pkpd} and \code{logistic} models, all
variables must be binary (or factor variables) as different values of
all parameters are calculated for all combinations of these variables
(except for the logistic model when a time-varying covariate is
present). It cannot be used when model is a function.}
\item{tvcov}{A list of vectors or matrices with time-varying
covariates for each individual (one column per variable), a matrix or
dataframe of such covariate values (if only one covariate), or an
object of class, \code{tvcov} (created by \code{\link[rmutil]{tvctomat}}).
If times are not the same as for responses, the list can be created with
\code{\link[rmutil]{gettvc}}. If response has class, \code{repeated}, with a
\code{linear}, \code{logistic}, or \code{pkpd} model, the covariates
must be specified as a Wilkinson and Rogers formula unless none are
to be used. Only one time-varying covariate is allowed except for the
\code{linear model}; if more are required, set \code{model} equal to
the appropriate mean function. This argument cannot be used when model
is a function.}
\item{nest}{When \code{response} is a matrix, a vector of length equal
to the number of responses per individual indicating which responses
belong to which nesting category. Categoriess must be consecutive
increasing integers. This option should always be specified if nesting
is present. Ignored if response has class, \code{repeated}.}
\item{torder}{When the \code{linear model} is chosen, order of the
polynomial in time to be fitted.}
\item{interaction}{Vector of length equal to the number of
time-constant covariates, giving the levels of interactions between
them and the polynomial in time in the \code{linear model}.}
\item{transform}{Transformation of the response variable: \code{identity},
\code{exp}, \code{square}, \code{sqrt}, or \code{log}.}
\item{link}{Link function for the location: \code{identity}, \code{exp},
\code{square}, \code{sqrt}, or \code{log}. For the \code{linear model},
if not the \code{identity}, initial estimates of the regression
parameters must be supplied (intercept, polynomial in time,
time-constant covariates, time-varying covariates, in that order).}
\item{autocorr}{The form of the autocorrelation function:
\code{exponential} is the usual \eqn{\rho^{|t_i-t_j|}}{rho^|t_i-t_j|};
\code{gaussian} is \eqn{\rho^{(t_i-t_j)^2}}{rho^((t_i-t_j)^2)};
\code{cauchy} is \eqn{1/(1+\rho(t_i-t_j)^2)}{1/(1+rho(t_i-t_j)^2)};
\code{spherical} is
\eqn{((|t_i-t_j|\rho)^3-3|t_i-t_j|\rho+2)/2}{((|t_i-t_j|rho)^3-3|t_i-t_j|rho+2)/2}
for \eqn{|t_i-t_j|\leq1/\rho}{|t_i-t_j|<=1/rho} and zero otherwise;
\code{IOU} is the integrated
Ornstein-Uhlenbeck process, \eqn{(2\rho \min(t_i,t_j)+\exp(-\rho t_i)
+\exp(-\rho t_j)-1 -\exp(\rho|ti-t_j|))/2\rho^3}{(2rho min(t_i,t_j)+exp(-rho t_i)
+exp(-rho t_j)-1 -exp(rho|ti-t_j|))/2rho^3}.}
\item{pell}{Initial estimate of the power parameter of the
multivariate power exponential distribution, of the degrees of
freedom parameter of the multivariate Student t distribution, or of
the asymmetry parameter of the multivariate Laplace distribution.
If not supplied for the latter, asymmetry depends on the regression
equation in \code{model}.}
\item{preg}{Initial parameter estimates for the regression model.
Only required for \code{linear model} if the \code{link} is not the
\code{identity} or a variance (dispersion) function is fitted.}
\item{pvar}{Initial parameter estimate for the variance or
dispersion. If more than one value is provided, the log
variance/dispersion depends on a polynomial in time. With the
\code{pkpd model}, if four values are supplied, a nonlinear regression
for the variance/dispersion is fitted.}
\item{varfn}{The builtin variance (dispersion) function has the
variance/dispersion proportional to a function of the location:
pvar*v(mu) = \code{identity} or \code{square}. If pvar contains two
initial values, an additive constant is included: pvar(1)+pvar(2)*v(mu).
Otherwise, either a function or a formula beginning with ~, specifying
either a linear regression function in the Wilkinson and Rogers
notation or a general function with named unknown parameters for the
log variance can be supplied. If it contains unknown parameters, the
keyword \code{mu} may be used to specify a function of the location
parameter.}
\item{pre}{Zero, one or two parameter estimates for the variance
components, depending on the number of levels of nesting.}
\item{par}{If supplied, an initial estimate for the autocorrelation
parameter.}
\item{delta}{Scalar or vector giving the unit of measurement
for each response value, set to unity by default. For example, if a
response is measured to two decimals, \code{delta=0.01}. Ignored if
response has class, \code{response} or \code{repeated}.}
\item{shfn}{If TRUE, the supplied variance (dispersion) function
depends on the mean function. The name of this mean function must be
the last argument of the variance/dispersion function.}
\item{common}{If TRUE, \code{mu} and \code{varfn} must both be either
functions with, as argument, a vector of parameters having some or all
elements in common between them so that indexing is in common
between them or formulae with unknowns. All parameter estimates must
be supplied in \code{preg}. If FALSE, parameters are distinct between
the two functions and indexing starts at one in each function.}
\item{envir}{Environment in which model formulae are to be
interpreted or a data object of class, \code{repeated}, \code{tccov},
or \code{tvcov}; the name of the response variable should be given in
\code{response}. If \code{response} has class \code{repeated}, it is
used as the environment.}
\item{others}{Arguments controlling \code{\link{nlm}}.}
\item{z}{An object of class, \code{elliptic}.}
\item{recursive}{If TRUE, recursive residuals or fitted values are
given; otherwise, marginal ones. In all cases, raw residuals are
returned, not standardized by the standard deviation (which may be
changing with covariates or time).}
}
\value{
A list of class \code{elliptic} is returned that contains all of the
relevant information calculated, including error codes.
}
\references{
Lindsey, J.K. (1999) Multivariate elliptically-contoured distributions
for repeated measurements. Biometrics 55, 1277-1280.

Kotz, S., Kozubowski, T.J., and Podgorski, K. (2001) The Laplace
Distribution and Generalizations. A Revisit with Applications to
Communications, Economics, Engineering, and Finance. Basel:
Birkhauser, Ch. 6.
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[rmutil]{dpowexp}},
\code{\link[rmutil]{dskewlaplace}}, \code{\link[rmutil]{finterp}},
\code{\link[repeated]{gar}}, \code{\link[rmutil]{gettvc}},
\code{\link[repeated]{gnlmix}}, \code{\link[repeated]{glmm}},
\code{\link[repeated]{gnlmm}}, \code{\link[gnlm]{gnlr}},
\code{\link[rmutil]{iprofile}}, \code{\link[repeated]{kalseries}},
\code{\link[rmutil]{mprofile}}, \code{\link[growth]{potthoff}},
\code{\link[rmutil]{read.list}}, \code{\link[rmutil]{restovec}},
\code{\link[rmutil]{rmna}}, \code{\link[rmutil]{tcctomat}},
\code{\link[rmutil]{tvctomat}}.
}
\examples{
# linear models
y <- matrix(rnorm(40),ncol=5)
x1 <- gl(2,4)
x2 <- gl(2,1,8)
# independence with time trend
elliptic(y, ccov=~x1, torder=2)
# AR(1)
elliptic(y, ccov=~x1, torder=2, par=0.1)
elliptic(y, ccov=~x1, torder=3, interact=3, par=0.1)
# random intercept
elliptic(y, ccov=~x1+x2, interact=c(2,0), torder=3, pre=2)
#
# nonlinear models
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
conc <- matrix(rnorm(40,mu(log(c(1,0.3,0.2))),sqrt(shape(log(c(0.1,0.4))))),
	ncol=20,byrow=TRUE)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=TRUE)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
# with builtin function
# independence
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5))
# AR(1)
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5),
	par=0.1)
# add variance function
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5),
	par=0.1, varfn=shape, pvar=log(c(0.5,0.2)))
# multivariate power exponential distribution
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5),
	par=0.1, varfn=shape, pvar=log(c(0.5,0.2)), pell=1,
	distribution="power exponential")
# multivariate Student t distribution
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5),
	par=0.1, varfn=shape, pvar=log(c(0.5,0.2)), pell=5,
	distribution="Student t")
# multivariate Laplace distribution
elliptic(conc, model="pkpd", preg=log(c(0.5,0.4,0.1)), dose=c(2,5),
	par=0.1, varfn=shape, pvar=log(c(0.5,0.2)),
	distribution="Laplace")
# or equivalently with user-specified function
# independence
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)))
# AR(1)
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)), par=0.1)
# add variance function
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)), par=0.1,
	varfn=shape, pvar=log(c(0.5,0.2)))
# multivariate power exponential distribution
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)), par=0.1,
	varfn=shape, pvar=log(c(0.5,0.2)), pell=1,
	distribution="power exponential")
# multivariate Student t distribution
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)), par=0.1,
	varfn=shape, pvar=log(c(0.5,0.2)), pell=5,
	distribution="Student t")
# multivariate Laplace distribution
elliptic(conc, model=mu, preg=log(c(0.5,0.4,0.1)), par=0.1,
	varfn=shape, pvar=log(c(0.5,0.2)), pell=5,
	distribution="Laplace")
# or with user-specified formula
# independence
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),
	volume=log(0.1)))
# AR(1)
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	par=0.1)
# add variance function
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	varfn=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	par=0.1, pvar=list(b1=log(0.5),b2=log(0.2)))
# variance as function of the mean
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	varfn=~d*log(mu),shfn=TRUE,par=0.1, pvar=list(d=1))
# multivariate power exponential distribution
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	varfn=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	par=0.1, pvar=list(b1=log(0.5),b2=log(0.2)), pell=1,
	distribution="power exponential")
# multivariate Student t distribution
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	varfn=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	par=0.1, pvar=list(b1=log(0.5),b2=log(0.2)), pell=5,
	distribution="Student t")
# multivariate Laplace distribution
elliptic(conc, model=~exp(absorption-volume)*
	dose/(exp(absorption)-exp(elimination))*
	(exp(-exp(elimination)*times)-exp(-exp(absorption)*times)),
	preg=list(absorption=log(0.5),elimination=log(0.4),volume=log(0.1)),
	varfn=~exp(b1-b2)*times*dose*exp(-exp(b1)*times),
	par=0.1, pvar=list(b1=log(0.5),b2=log(0.2)), pell=5,
	distribution="Laplace")
#
# generalized logistic regression with square-root transformation
# and square  link
times <- rep(seq(10,200,by=10),2)
mu <- function(p) {
	yinf <- exp(p[2])
	yinf*(1+((yinf/exp(p[1]))^p[4]-1)*exp(-yinf^p[4]
		*exp(p[3])*times))^(-1/p[4])}
y <- matrix(rnorm(40,sqrt(mu(c(2,1.5,0.05,-2))),0.05)^2,ncol=20,byrow=TRUE)
y[,2:20] <- y[,2:20]+0.5*(y[,1:19]-matrix(mu(c(2,1.5,0.05,-2)),
	ncol=20,byrow=TRUE)[,1:19])
y <- ifelse(y>0,y,0.01)
# with builtin function
# independence
elliptic(y, model="logistic", preg=c(2,1,0.1,-1), trans="sqrt",
	link="square")
# the same model with AR(1)
elliptic(y, model="logistic", preg=c(2,1,0.1,-1), trans="sqrt",
	link="square", par=0.4)
# the same model with AR(1) and one component of variance
elliptic(y, model="logistic", preg=c(2,1,0.1,-1),
	trans="sqrt", link="square", pre=1, par=0.4)
# or equivalently with user-specified function
# independence
elliptic(y, model=mu, preg=c(2,1,0.1,-1), trans="sqrt",
	link="square")
# the same model with AR(1)
elliptic(y, model=mu, preg=c(2,1,0.1,-1), trans="sqrt",
	link="square", par=0.4)
# the same model with AR(1) and one component of variance
elliptic(y, model=mu, preg=c(2,1,0.1,-1),
	trans="sqrt", link="square", pre=1, par=0.4)
# or equivalently with user-specified formula
# independence
elliptic(y, model=~exp(yinf)*(1+((exp(yinf-y0))^b4-1)*
	exp(-exp(yinf*b4+b3)*times))^(-1/b4),
	preg=list(y0=2,yinf=1,b3=0.1,b4=-1), trans="sqrt", link="square")
# the same model with AR(1)
elliptic(y, model=~exp(yinf)*(1+((exp(yinf-y0))^b4-1)*
	exp(-exp(yinf*b4+b3)*times))^(-1/b4),
	preg=list(y0=2,yinf=1,b3=0.1,b4=-1), trans="sqrt",
	link="square", par=0.1)
# add one component of variance
elliptic(y, model=~exp(yinf)*(1+((exp(yinf-y0))^b4-1)*
	exp(-exp(yinf*b4+b3)*times))^(-1/b4),
	preg=list(y0=2,yinf=1,b3=0.1,b4=-1),
	trans="sqrt", link="square", pre=1, par=0.1)
#
# multivariate power exponential and Student t distributions for outliers
y <- matrix(rcauchy(40,mu(c(2,1.5,0.05,-2)),0.05),ncol=20,byrow=TRUE)
y[,2:20] <- y[,2:20]+0.5*(y[,1:19]-matrix(mu(c(2,1.5,0.05,-2)),
	ncol=20,byrow=TRUE)[,1:19])
y <- ifelse(y>0,y,0.01)
# first with normal distribution
elliptic(y, model="logistic", preg=c(1,1,0.1,-1))
elliptic(y, model="logistic", preg=c(1,1,0.1,-1), par=0.5)
# then power exponential
elliptic(y, model="logistic", preg=c(1,1,0.1,-1), pell=1,
	distribution="power exponential")
elliptic(y, model="logistic", preg=c(1,1,0.1,-1), par=0.5, pell=1,
	distribution="power exponential")
# finally Student t
elliptic(y, model="logistic", preg=c(1,1,0.1,-1), pell=1,
	distribution="Student t")
elliptic(y, model="logistic", preg=c(1,1,0.1,-1), par=0.5, pell=1,
	distribution="Student t")
}
\keyword{models}

\eof
\name{growth}
\title{Normal Theory Repeated Measurements Library}
\alias{growth}
\description{
\code{\link[growth]{carma}}			Normal Theory Repeated Measurements Models

\code{\link[growth]{corgram}}			Calculate and Plot a Correlogram

\code{\link[growth]{elliptic}}		Multivariate Elliptically-contoured Nonlinear Repeated Measurements Models with Time-varying Covariates

\code{\link[growth]{pergram}}			Calculate and Plot a Periodogram

\code{\link[growth]{potthoff}}		Potthoff and Roy Growth Curve Model

\code{\link[growth]{rmaov}}			Split-plot ANOVA Model
}
\keyword{documentation}

\eof
\name{pergram}
\title{Calculate and Plot a Periodogram}
\alias{pergram}
\usage{
pergram(y)
plot.pergram(y, add=FALSE, lty=1, xlab="Frequency", ylab="Periodogram",
	main="Periodogram", ylim=c(0,max(po[,2])))
plot.cum.pergram(y, xlab="Frequency", ylab="Periodogram",
	main="Cumulative periodogram",
	ylim=c(0,max(cpo+1.358/(a+0.12+0.11/a))))
}
\alias{plot.pergram}
\alias{plot.cum.pergram}
\description{
\code{pergram} calculates the values of a periodogram,
\code{plot.pergram} plots it, and \code{plot.cum.pergram} plots the
corresponding cumulative periodogram.
}
\arguments{
\item{y}{A time series vector.}
\item{add}{If TRUE, adds a new periodogram to an existing plot.}
\item{others}{Plotting parameters}
}
\value{
\code{pergram} prints and returns a two-column matrix of class,
\code{pergram}, containing the periodogram.
}
\author{J.K. Lindsey}
\examples{
y <- rnorm(100)
print(z <- pergram(y))
plot(z)
plot.cum(z)
}
\keyword{hplot}

\eof
\name{potthoff}
\title{Potthoff and Roy Growth Curve Model}
\alias{potthoff}
\usage{
potthoff(response, x, ccov=NULL, times=NULL, torder=0, orthogonal=TRUE)
}
\description{
\code{potthoff} fits the Potthoff and Roy repeated measurements growth
curve model with unstructured covariance matrix to completely balanced
data.
}
\arguments{
\item{response}{A matrix or dataframe of response values.}
\item{x}{A matrix defining the complete intersubject differences or a
Wilkinson and Rogers formula that will create one.}
\item{ccov}{A matrix of columns of the baseline covariates to be
actually fitted, with one row per individual or a W&R formula that
will create one.}
\item{times}{A vector of unequally spaced times when they are the same
for all individuals. Not necessary if equally spaced.}
\item{torder}{Order of the polynomial in time to be fitted. If
non-numeric, the full model in time is fitted.}
\item{orthogonal}{If TRUE, uses orthogonal polynomials for time,
otherwise only centres times at their mean.}
}
\value{
A list of class potthoff is returned. 
}
\author{J.K. Lindsey}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}}, \code{\link{lm}}.
}
\examples{
y <- matrix(rnorm(40),ncol=5)
x <- gl(2,4)
# full model with treatment effect
potthoff(y, ~x, torder="f", ccov=~x)
# no time trend with treatment effect
potthoff(y, ~x, torder=0, ccov=~x)
# quadratic time with treatment effect
potthoff(y, ~x, torder=2, ccov=~x)
# full model without treatment effect
potthoff(y, ~x, torder="f")
# linear time without treatment effect
potthoff(y, ~x, torder=1)
}
\keyword{models}

\eof
\name{rmaov}
\title{Split-plot ANOVA Model}
\alias{rmaov}
\usage{
rmaov(response, tvcov=NULL, ccov=NULL, analysis=TRUE)
}
\description{
\code{rmaov} performs the classical balanced split-plot ANOVA, with
\code{summary} providing the table. This is the so-called repeated
measures ANOVA.

For unbalanced data, \code{\link[growth]{elliptic}} will
perform the analysis for one or two levels of nesting.
}
\arguments{
\item{response}{A matrix or dataframe of response values with units as
rows and repeated measures as columns.}
\item{tvcov}{A numeric vector or factor variable defining the
clusters. If there are several levels of nesting, a matrix or
dataframe with columns of such variables defining the nested clusters
starting with the highest level (that is, from slowest to fastest
varying). If not provided, each response value of a unit is assumed to
belong to a different cluster (that is, one factor with
\code{ncol(response)} levels is assumed).}
\item{ccov}{A vector or factor variable for one inter-subject
covariate or a matrix, dataframe, or list of several such variables.}
\item{analysis}{If FALSE, the design matrix is set up, but the
analysis is not performed.}
}
\value{
The fitted model is returned. 
}
\author{Ralf Goertz (ralf.goertz@uni-jena.de)}
\seealso{
\code{\link[growth]{carma}}, \code{\link[growth]{elliptic}}, \code{\link{lm}},
\code{\link[growth]{potthoff}}.
}
\examples{
# vision data for 7 individuals, with response a 7x8 matrix
# two levels of nesting: 4 levels of power for each eye
y <- matrix(rnorm(56),ncol=8)
tvc <- data.frame(eye=c(rep(1,4),rep(2,4)),power=c(1:4,1:4))
summary(rmaov(y, tvc))
}
\keyword{models}

\eof
