\name{ioprofile}
\title{Produce Individual Ordinal Time Profiles for Plotting}
\usage{
plot(ioprofile(z,curve.type="mean"),nind=1,observed=T,main=NULL,
     xlab=NULL,ylab=NULL,xlim=NULL,ylim=NULL,lty=NULL,pch=NULL,
     add=F,axes=F,bty="n",at=NULL,touch=F,...)
}
\alias{ioprofile.default}
\alias{ioprofile.kalordinal}
\alias{plot.ioprofile}
\description{
  \code{ioprofile} is used for plotting individual ordinal profiles over
  time for objects obtained from dynamic models. It produces output for
  plotting recursive undelying means, recursive highest probabilities,
  and recursive cumulative probabilities for individual ordinal time
  profiles from such models.

  See \code{\link{moprofile}} for plotting marginal ordinal profiles.
}
\arguments{
  \item{z}{An object of class \code{kalordinal}, from
    \code{\link{kalord}}.}
  \item{curve.type}{Specifies the type of curves to be plotted. Must
    either be "mean" for recursive underlying means, "probability" for
    recursive highest probabilities, "both" for recursive predictions
    (recursive underlying means and recursive highest probabilities), or
    "cumulative" for recursive cumulative probabilities.}
  \item{nind}{Observation number(s) of individual(s) to be plotted.}
  \item{observed}{If TRUE, adds the corresponding observations to the
    plot. If cumulative curves have been chosen, they are added as a
    subtitle.}
  \item{main}{A main title for the plot.}
  \item{xlab}{A label for the x-axis.}
  \item{ylab}{A label for the y-axis.}
  \item{xlim}{The x limits (min,max) of the plot.}
  \item{ylim}{The y limits (min,max) of the plot.}
  \item{lty}{A vector of integers or character strings specifying the
    line type to be used as the default in plotting lines. For further
    information, see \code{\link{par}}.}
  \item{pch}{A vector of integers or single characters specifying
    symbols to be used as the default in plotting points. For further
    information, see \code{\link{par}}.}
  \item{add}{If TRUE, the graph is added to an existing plot.}
  \item{axes}{If FALSE, axes are not drawn around the plot.}
  \item{bty}{A character string which determined the type of box which
    is drawn about plots. For further information, see
    \code{\link{par}}.}
  \item{at}{The points at which tick-marks are to be drawn. For further
    information, see \code{\link{axis}}.}
  \item{touch}{If TRUE, the x-axis and y-axis will touch each other.}
}
\value{
  \code{ioprofile} returns information ready for plotting by
  \code{plot.ioprofile}.
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{kalord}}, \code{\link{moprofile}},
  \code{\link{plot.ordinal}}, \code{\link{poprofile}}.
}
\examples{
library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")

# Recursive mean profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"mean"),nind=1)
plot(ioprofile(z,"mean"),nind=5)
plot(ioprofile(z,"mean"),nind=c(1,5))
plot(ioprofile(z,"mean"),nind=12)
par(mfrow=c(1,1))

# Recursive highest probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"prob"),nind=1)
plot(ioprofile(z,"prob"),nind=5)
plot(ioprofile(z,"prob"),nind=c(1,5))
plot(ioprofile(z,"prob"),nind=12)
par(mfrow=c(1,1))

# Recursive predicted profiles.
par(mfrow=c(2,3))
plot(ioprofile(z,"both"),nind=1)
plot(ioprofile(z,"both"),nind=5)
plot(ioprofile(z,"both"),nind=12)
plot(ioprofile(z,"both"),nind=c(1,5,12),add=T)
par(mfrow=c(1,1))

# Recursive cumulative probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"cum"),nind=1)
plot(ioprofile(z,"cum"),nind=5)
plot(ioprofile(z,"cum"),nind=c(1,5),add=T)
par(mfrow=c(1,1))

rm(w,z)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Proportional-odds model with time-constant covariate with a Markov dependence.
z <- kalord(w,distribution="proportional-odds",ccov=~distance,
            preg=c(-1.89,11.652,-0.199),pinit=3.111,pdep=0.217,dep="Markov")

# Recursive mean profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"mean"),nind=1)
plot(ioprofile(z,"mean"),nind=268)
plot(ioprofile(z,"mean"),nind=c(1,268))
plot(ioprofile(z,"mean"),nind=117)
par(mfrow=c(1,1))

# Recursive highest probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"prob"),nind=1)
plot(ioprofile(z,"prob"),nind=268)
plot(ioprofile(z,"prob"),nind=c(1,268))
plot(ioprofile(z,"prob"),nind=117)
par(mfrow=c(1,1))

# Recursive predicted profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"both"),nind=120)
plot(ioprofile(z,"both"),nind=268)
plot(ioprofile(z,"both"),nind=c(1,117),add=T)
par(mfrow=c(1,1))

# Recursive cumulative probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"cum"),nind=1)
plot(ioprofile(z,"cum"),nind=268)
plot(ioprofile(z,"cum"),nind=c(117,120),add=T)
par(mfrow=c(1,1))

rm(w,z)
}
\keyword{hplot}

\eof
\name{kalord}
\title{Repeated Measurements Models for Ordinal Variables with
  Frailty or Serial Dependence}
\usage{
kalord(response,times=NULL,distribution="multinomial",
       depend="independence",mu=NULL,ccov=NULL,tvcov=NULL,torder=0,
       interaction=NULL,preg=NULL,ptvc=NULL,pinitial=1,pdepend=NULL,
       envir=sys.frame(sys.parent()),optimize=T,print.level=0,
       ndigit=10,gradtol=0.00001,steptol=0.00001,fscale=1,
       iterlim=100,typsiz=abs(p),stepmax=10*sqrt(p%*%p))
}
\alias{print.kalordinal}
\alias{deviance.kalordinal}
\alias{fitted.kalordinal}
\description{
  \code{kalord} is designed to handle repeated measurements models with
  time-varying covariates. The distributions have two extra parameters
  as compared to the parameterization of the logistic distribution
  specified by \code{distribution}. Dependence among observations on a
  unit can be through gamma frailties (a type of random effect) or
  serial dependence over time.

  Nonlinear regression models can be supplied as formulae where
  parameters are unknowns in which case factor variables cannot be used
  and parameters must be scalars. (See \code{\link{finterp}}.)

  Marginal, individual and predicted profiles can be plotted using
  \code{\link{moprofile}}, \code{\link{ioprofile}} and
  \code{\link{poprofile}}.

  If the responses on a unit are clustered, not longitudinal, use the
  frailty dependence.
}
\arguments{
  \item{response}{A list of two column matrices with responses and
    corresponding times for each individual, one matrix or dataframe of
    response values, or an object of class, \code{response} (created by
    \code{\link{restovec}}) or \code{repeated} (created by
    \code{\link{rmna}} or \code{\link{lvna}}). If the \code{repeated}
    data object contains more than one response variable, give that
    object in \code{envir} and give the name of the response variable to
    be used here.}
  \item{times}{When response is a matrix, a vector of possibly unequally
    spaced times when they are the same for all individuals or a matrix
    of times. Not necessary if equally spaced. Ignored if response has
    class, \code{response} or \code{repeated}.}
  \item{distribution}{Specifies the parameterization of the logistic
    distribution to put in the Pareto distribution. Choices are binary,
    multinomial, continuation-ratio, and proportional-odds.}
  \item{depend}{Type of dependence. Choices are \code{independence},
    \code{Markov}, \code{serial}, and \code{frailty}.}
  \item{mu}{A regression function for the location parameter or a
    formula beginning with ~, specifying either a linear regression
    function in the Wilkinson and Rogers notation or a general function
    with named unknown parameters. The regression function must not
    contain intercepts. Give the initial estimates in \code{preg} or in
    \code{ptvc}.}
  \item{ccov}{A vector or matrix containing time-constant baseline
    covariates with one row per individual, a model formula using
    vectors of the same size, or an object of class, \code{tccov}
    (created by \code{\link{tcctomat}}). If response has class,
    \code{repeated}, the covariates must be supplied as a Wilkinson and
    Rogers formula unless none are to be used or \code{mu} is given.}
  \item{tvcov}{A list of matrices with time-varying covariate values,
    observed at the event times in \code{response}, for each individual
    (one column per variable), one matrix or dataframe of such covariate
    values, or an object of class, \code{tvcov} (created by
    \code{\link{tvctomat}}). If a time-varying covariate is observed at
    arbitrary time, \code{\link{gettvc}} can be used to find the most
    recent values for each response and create a suitable list. If
    response has class, \code{repeated}, the covariates must be supplied
    as a Wilkinson and Rogers formula unless none are to be used or
    \code{mu} is given.}
  \item{torder}{The order of the polynomial in time to be fitted.}
  \item{interaction}{Vector of length equal to the number of
    time-constant covariates, giving the levels of interactions between
    them and the polynomial in time in the \code{linear model}.}
  \item{preg}{Initial parameter estimates for the regression model:
    intercept, one for each covariate in \code{ccov}, and \code{torder}
    plus sum(\code{interaction}). If \code{mu} is a formula with unknown
    parameters, their estimates must be supplied either in their order
    of appearance in the expression or in a named list.}
  \item{ptvc}{Initial parameter estimates for the coefficients of the
    time-varying covariates, as many as in \code{tvcov}.}
  \item{pinitial}{An initial estimate for the initial parameter, if set
    to \code{NULL} this parameter will be fixed at zero. (With
    \code{frailty} dependence, this is the frailty parameter.)}
  \item{pdepend}{An initial estimate for the serial dependence
    parameter.}
  \item{envir}{Environment in which model formulae are to be interpreted
    or a data object of class, \code{repeated}, \code{tccov}, or
    \code{tvcov}; the name of the response variable should be given in
    \code{response}. If \code{response} has class \code{repeated}, it is
    used as the environment.}
  \item{optimize}{If set to \code{TRUE} then \code{\link{nlm}} is used
    to perform the numerical optimization of the likelihood function,
    otherwise if set to \code{FALSE} no optimization is performed.}
  \item{others}{Arguments controlling \code{\link{nlm}}.}
}
\value{
  A list of classes \code{kalordinal} and \code{recursive} is returned.
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{finterp}}, \code{\link{gettvc}}, \code{\link{ioprofile}},
  \code{\link{lvna}}, \code{\link{moprofile}},
  \code{\link{plot.ordinal}}, \code{\link{poprofile}},
  \code{\link{restovec}}, \code{\link{rmna}}, \code{\link{tcctomat}},
  \code{\link{tvctomat}}.
}
\examples{
library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant covariate.
kalord(w,distribution="binary",ccov=~age,preg=c(3.9507,-0.0308),pinit=NULL)

# Time-varying covariate.
kalord(w,distribution="binary",tvcov=~times,preg=1.832,ptvc=0.0573,pinit=NULL)

# Time-constant and time-varying covariate.
kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
       ptvc=c(3.888,-0.0289,-0.642,-0.366,-0.314,-0.154,-0.114,0.057),pinit=NULL)

# Time-constant and time-varying covariate with a frailty dependence.
kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
       ptvc=c(4.43391,-0.03128,-0.62439,-0.37596,-0.33064,-0.17095,-0.12216,-0.09096),
       pinit=0.1196,dep="frailty")

rm(w)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Continuation-ratio model with time-constant covariate with a serial dependence.
kalord(w,distribution="continuation-ratio",ccov=~distance,preg=c(-1.907,7.7,-0.162),
       pinit=2.55,pdep=0.328,dep="serial")

# Proportional-odds model with time-constant covariate with a Markov dependence.
kalord(w,distribution="proportional-odds",ccov=~distance,preg=c(-1.89,11.652,-0.199),
	pinit=3.111,pdep=0.217,dep="Markov")

rm(w)
}
\keyword{models}

\eof
\name{lcr}
\title{Linear categorical regression}
\usage{
lcr(response=NULL,frequencies=NULL,mu=NULL,ccov=NULL,tvcov=NULL,
    times=F,pcoef=NULL,plink=NULL,distribution=NULL,
    direction=NULL,transformation=NULL,link=NULL,
    envir=parent.frame(),steptol=1e-04,iterlim=100)
}
\alias{print.lcr}
\alias{extractAIC.lcr}
\alias{deviance.lcr}
\alias{fitted.lcr}
\alias{names.lcr}
\description{
  \code{lcr} is used to fit a linear categorical regression possibly
  including time-constant and/or time-varying covariates.

  Marginal and individual profiles can be plotted using
  \code{\link{moprofile}} and \code{\link{ioprofile}}.
}
\arguments{
  \item{response}{A response is a vector with cell indecees representing
    entries of a contengency table. A vector or an object of class
    \code{response} (created by \code{\link{restovec}}) or
    \code{repeated} (created by \code{\link{rmna}} or
    \code{\link{lvna}}) containing the response variable information. If
    the \code{repeated} data object contains more than one response
    variable, give that object in \code{envir} and give the name of the
    response variable to be used here.}
  \item{frequencies}{A vector containing the frequencies respectively
    corresponding to the cell entries of the contengency table described
    by the response. If the response is an object of class
    \code{response} or \code{repeated}, the frequencies should be
    included in this object as weights. If the frequencies are omited,
    it is then assumed that each response entry corresponds to an event
    (the frequencies will be by default a vector of 1's).}
  \item{mu}{A formula beginning with ~ specifying a linear regression
    function in the Wilkinson and Rogers notation. Give the initial
    estimates in \code{pcoef}.}
  \item{ccov}{A matrix or an object of class \code{tccov} (created by
    \code{\link{tcctomat}}) containing the time-constant baseline
    covariates.}
  \item{tvcov}{A matrix or an object of class \code{tvcov} (created by
    \code{\link{tvctomat}}) containing the time-varying covariate
    values.}
  \item{times}{A vector containing the times, if the \code{response} is
    not an object of class \code{repeated} or \code{response}.}
  \item{pcoef}{Initial parameter estimates for the regression model: If
    "binary", a vector containing an intercept plus one parameter for
    each covariate. If "mutinomial", a vector containing, for each
    category except the reference one, an intercept plus one parameter
    for each covariate. If "simplified mutinomial" or "continuation
    ratio" (upwards or downwards) or "proportional odds" or "adjacent
    categories", a vector containing an intercept for each category
    except the reference one plus one parameter for each covariate.}
  \item{plink}{Initial parameter estimates for the link function. These
    parameters are fixed at the given value.}
  \item{distribution}{A string containing one of: "binary" (default if
    two categories), "multinomial" (default if more than two
    categories), "simplified multinomial", "continuation-ratio",
    "proportional odds", or "adjacent categories".}
  \item{reference}{Only used if the model is "continuation ratio" then
    reference must be a string corresponding either to "upwards"
    (default) or "downwards".}
  \item{transformation}{A string containing one of: "identity"
    (default), "sqrt", "log", "logit", "cloglog", "square", "exp", or
    "loglog".}
  \item{link}{If "binary" or "proportional odds", a string containing
    one of: "logit" (default), "probit", "loglog", "cloglog", "uniform",
    "log-normal", "exponential", "Pareto", "Cauchy", "Laplace", "Levy",
    "simplex", "gamma", "Weibull", "inverse Gauss", "t", "chi-square",
    "gen logistic", "gen extreme value", "Box-Cox", "power exponential",
    "Burr", "Hjorth", "beta", "stable", "gen gamma", "gen Weibull", "gen
    inverse Gauss", "F", "nc t", "nc chi-square", "Tukey", "nc beta", or
    "nc F".}
  \item{envir}{Environment in which model formulae are to be interpreted
    or a data object of class \code{repeated}, \code{tccov}, or
    \code{tvcov}. The name of the response variable should be given in
    \code{response}.
    If \code{response} has class \code{repeated}, it is used as the
    environment.}
  \item{steptol}{A positive scalar providing the minimum allowable
    relative step length.}
  \item{iterlim}{A positive integer specifying the maximum number of
    iterations to be performed.}
}
\details{
  There are seven possible types of models that can be fitted. These are
  a binary, multinomial, simplified multinomial, continuation-ratio
  (upwards and downwards), proportional-odds, or adjacent categories.
  For each of these models, covariates can be included. All explanatory
  variables are taken as continuous. One must therefore create dummy
  binary indicator variables (for example using \code{\link{wr}}), if a
  factor variable is to be included in a model.

  To obtain the regression coefficients, the linear system of equations
  is solved by using the first and second derivatives. This guarantees
  fast and stable convergence to the maximum likelihood estimates.
}
\value{
  A list of classes \code{lcr} and \code{repeated} is returned. This
  list is composed of: the function call (call), an object of class
  \code{response} (response), an object of class \code{tvcov} (tvcov)
  containing all covariates (even the time-constant ones), the
  frequencies (frequencies), whether the response is individual data or
  a contengency table (individual), the distribution used
  (distribution), the direction for "continuation ratio" models
  (direction), the transformation used (transformation), the link used
  (link), the length of the response (n), the number of levels of the
  response (nc), the number of covariates (ncv), the total number of
  individuals or events (events), the log-likelihood (likelihood), the
  linear regression estimates (coefficients), the standard errors of
  beta (se), the covariance matrix (covariance), the correlation matrix
  (correlations), the fitted probabilities (fitted), the categories
  containing the highest probabilities (pred), the cumulative
  probabilities (cpred), the number of iterations performed
  (iterations), the iteration limit (iterlim), the QR decomposition
  exact singularity indicator (info), and the second derivative
  singularity indicator (rank).
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{ioprofile}}, \code{\link{lvna}}, \code{\link{moprofile}},
  \code{\link{rmna}}, \code{\link{restovec}}, \code{\link{tcctomat}},
  \code{\link{tvctomat}}.
}
\examples{
library(ordinal)

#
# Binary example:
#
data(cardiac)

resp <- cardiac[,1:4]
freq <- cardiac[,11]

age <- cardiac[,5]
sex <- cardiac[,6]
pmi <- cardiac[,7]
dia <- cardiac[,8]
ren <- cardiac[,9]
cop <- cardiac[,10]

rm(cardiac)

y <- restovec(resp,times=T,weights=freq,type="ordinal")

tcc <- tcctomat(age,name="age")
tcc <- tcctomat(sex,name="sex",oldccov=tcc)
tcc <- tcctomat(pmi,name="pmi",oldccov=tcc)
tcc <- tcctomat(dia,name="dia",oldccov=tcc)
tcc <- tcctomat(ren,name="ren",oldccov=tcc)
tcc <- tcctomat(cop,name="cop",oldccov=tcc)

tvc <- tvctomat(matrix(times(y)^2,ncol=4,byrow=T),name="times2")

w <- rmna(y,ccov=tcc,tvcov=tvc)

rm(resp,freq,age,sex,pmi,dia,ren,cop,y,tcc,tvc)

lcr(w)
lcr(w,mu=~times)
lcr(w,mu=~age+sex+times+times2)
lcr(w,mu=~age+sex+pmi+dia+ren+cop+pmi:dia+pmi:cop+dia:cop+times)
lcr(w,mu=~age+sex+pmi+dia+ren+cop+pmi:dia+pmi:cop+dia:cop+times+times2)

rm(w)

#
# Multinomial example:
#
data(criminal)

resp <- criminal[,2]-1
freq <- criminal[,5]

race <- criminal[,3]-1
county <- criminal[,4]-1
trial <- as.factor(criminal[,1])

rm(criminal)

y <- restovec(resp,times=F,weights=freq,type="ordinal")

tcc <- tcctomat(race,name="race")
tcc <- tcctomat(county,name="county",oldccov=tcc)
tcc <- tcctomat(trial,name="trial",oldccov=tcc)

w <- rmna(y,ccov=tcc)

rm(resp,freq,race,county,trial,y,tcc)

lcr(w)
lcr(w,mu=~race)
lcr(w,mu=~race+county)
lcr(w,mu=~race+county+trial)

#
# Simplified multinomial example:
#
lcr(w,dist="simpl")
lcr(w,dist="simpl",mu=~race)
lcr(w,dist="simpl",mu=~race+county)
lcr(w,dist="simpl",mu=~race+county+trial)

rm(w)

#
# Continuation ratio (upwards) example:
#
data(tmi)

resp <- tmi[,1:4]-1
freq <- tmi[,6]

cov <- matrix(tmi[,5],ncol=1,dimnames=list(NULL,"distance"))

rm(tmi)

y <- restovec(resp,times=T,weights=freq,type="ordinal")

tcc <- tcctomat(cov,name="distance")

w <- rmna(y,ccov=tcc)

rm(resp,freq,cov,y,tcc)

lcr(w,distribution="cont")
lcr(w,mu=~distance,distribution="cont")
lcr(w,mu=~distance+times,distribution="cont")

#
# Continuation ratio (downwards) example:
#
lcr(w,distribution="cont",direc="down")
lcr(w,distribution="cont",direc="down",mu=~distance)
lcr(w,distribution="cont",direc="down",mu=~distance+times)

#
# Proportional odds example:
#
lcr(w,distribution="prop")
lcr(w,distribution="prop",mu=~distance)
lcr(w,distribution="prop",mu=~distance+times)

#
# Adjacent categories example:
#
lcr(w,distribution="adj")
lcr(w,distribution="adj",mu=~distance)
lcr(w,distribution="adj",mu=~distance+times)

#
# Example using links:
#
lcr(w,distribution="prop",mu=~distance)
lcr(w,distribution="prop",mu=~distance,link="probit",pcoef=c(-1.3634,0.589,0.1709))
lcr(w,distribution="prop",mu=~distance,link="log-normal",transform="log",pcoef=c(-1.3634,0.589,0.1709))
lcr(w,distribution="prop",mu=~distance,link="Cauchy",pcoef=c(-2.9979,0.6297,0.5164))
lcr(w,distribution="prop",mu=~distance,link="Laplace",pcoef=c(-1.6946,0.5448,0.2531))
lcr(w,distribution="prop",mu=~distance,link="gen logistic",pcoef=c(-1.691,3.2053,0.4578),plink=2)
lcr(w,distribution="prop",mu=~distance,link="gen extreme value",transform="logit",pcoef=c(-2.9815,2.3526,0.6966),plink=1)
lcr(w,distribution="prop",mu=~distance,link="gen extreme value",transform="logit",pcoef=c(-5.8473,-1.6886,0.3214),plink=1/2)
lcr(w,distribution="prop",mu=~distance,link="power exponential",pcoef=c(-3.3892,1.0895,0.5061),plink=1/2)
lcr(w,distribution="prop",mu=~distance,link="stable",pcoef=c(-1.9281,0.8331,0.2417),plink=c(0,2))
lcr(w,distribution="prop",mu=~distance,link="nc F",transform="log",pcoef=c(-2.8999,2.2461,0.5254),plink=c(1,1,1))
lcr(w,distribution="prop",mu=~distance,link="nc F",transform="log",pcoef=c(-3.318,2.091,0.382),plink=c(1/2,3,2))

rm(w)
}
\keyword{models}

\eof
\name{moprofile}
\title{Produce Marginal Ordinal Time Profiles for Plotting}
\usage{
plot(moprofile(z,curve.type="probability"),nind=1,observed=T,
     main=NULL,xlab=NULL,ylab=NULL,xlim=NULL,ylim=NULL,lty=NULL,
     pch=NULL,add=F,axes=F,bty="n",at=NULL,touch=F,...)
}
\alias{moprofile.default}
\alias{moprofile.lcr}
\alias{moprofile.kalordinal}
\alias{plot.moprofile}
\description{
  \code{mprofile} is used for plotting marginal ordinal profiles over
  time for for objects obtained from models obtained. It produces output
  for plotting highest probabilities and cumulative probabilities for
  marginal ordinal time profiles.

  See \code{\link{iprofile}} for plotting individual ordinal profiles
  from recursive fitted values.
}
\arguments{
  \item{z}{An object of class \code{lcr} or \code{kalordinal}
    (\code{\link{kalord}}).}
  \item{curve.type}{Specifies the type of curves to be plotted. Must
    either be "probability" for highest probabilities or "cumulative"
    for cumulative probabilities.}
  \item{nind}{Observation number(s) of individual(s) to be plotted.}
  \item{observed}{If TRUE, adds the corresponding observations to the
    plot. If cumulative curves have been chosen, they are added as a
    subtitle.}
  \item{main}{A main title for the plot.}
  \item{xlab}{A label for the x-axis.}
  \item{ylab}{A label for the y-axis.}
  \item{xlim}{The x limits (min,max) of the plot.}
  \item{ylim}{The y limits (min,max) of the plot.}
  \item{lty}{A vector of integers or character strings specifying the
    line type to be used as the default in plotting lines. For further
    information, see \code{\link{par}}.}
  \item{pch}{A vector of integers or single characters specifying
    symbols to be used as the default in plotting points. For further
    information, see \code{\link{par}}.}
  \item{add}{If TRUE, the graph is added to an existing plot.}
  \item{axes}{If FALSE, axes are not drawn around the plot.}
  \item{bty}{A character string which determined the type of box which
    is drawn about plots. For further information, see
    \code{\link{par}}.}
  \item{at}{The points at which tick-marks are to be drawn. For further
    information, see \code{\link{axis}}.}
  \item{touch}{If TRUE, the x-axis and y-axis will touch each other.}
}
\value{
  \code{moprofile} returns information ready for plotting by
  \code{plot.moprofile}.
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{kalord}}, \code{\link{ioprofile}}, \code{\link{lcr}},
  \code{\link{plot.ordinal}}, \code{\link{poprofile}}.
}
\examples{
library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")

# Cumulative probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"cum"),nind=1)
plot(moprofile(z,"cum"),nind=117)
plot(moprofile(z,"cum"),nind=c(1000,3000),add=T)
par(mfrow=c(1,1))

# Highest probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"prob"),nind=2000)
plot(moprofile(z,"prob"),nind=3001)
plot(moprofile(z,"prob"),nind=c(3506,3521))
plot(moprofile(z,"prob"),nind=400)
par(mfrow=c(1,1))

rm(w,z)

#
# Ordinal data
#
data(obese)

resp <- cbind(codes(obese[,1])-1,codes(obese[,2])-1)
freq <- obese[,4]

age <- obese[,3]

rm(obese)

y <- restovec(resp,times=1:2,weights=freq,type="ordinal")

tcc <- tcctomat(age,name="age")

tvc <- tvctomat(matrix(times(y)^2,ncol=2),name="times2")

w <- rmna(y,ccov=tcc,tvcov=tvc)

rm(resp,freq,age,y,tcc,tvc)

z <- lcr(w,mu=~age*times+times2)

# Cumulative probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"cum"),nind=1)
plot(moprofile(z,"cum"),nind=4)
plot(moprofile(z,"cum"),nind=8:9,add=T)
par(mfrow=c(1,1))

# Highest probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"prob"),nind=1)
plot(moprofile(z,"prob"),nind=4)
plot(moprofile(z,"prob"),nind=c(8,9))
plot(moprofile(z,"prob"),nind=16)
par(mfrow=c(1,1))

rm(w,z)
}
\keyword{hplot}

\eof
\name{ordinal}
\title{Ordinal Library}
\description{
  \code{\link{ioprofile}}	Produce Individual Ordinal Time Profiles for			   Plotting

  \code{\link{kalord}}		Repeated Measurements Models for Ordinal			   Variables with Frailty or Serial Dependence

  \code{\link{lcr}}		Linear categorical regression

  \code{\link{moprofile}}	Produce Marginal Ordinal Time Profiles for			   Plotting

  \code{\link{plot.ordinal}}	Plot Ordinal Objects

  \code{\link{poprofile}}	Produce Predicted Ordinal Time Profiles for			   Plotting
}
\keyword{documentation}

\eof
\name{plot.ordinal}
\title{Plot Ordinal Objects}
\usage{
plot.ordinal(z,ccov=NULL,main=NULL,xlab=NULL,ylab=NULL,xlim=NULL,
             ylim=NULL,lty=NULL,add=F,axes=F,bty="n",at=NULL,
             touch=F,...)
}
\description{
  Plots the variables in data object of type \code{ordinal} with class
  \code{repeated} or \code{response}. If the data object contains
  time-constant covaiate(s) (\code{tccov}), a plot can be obtained for
  each level of one discrete covariate.
}
\arguments{
  \item{z}{A data object of class \code{repeated} or \code{response},
    and of type \code{ordinal}.}
  \item{ccov}{The name of a discrete time-constant covariate present in
    the data object of type \code{ordinal}.}
  \item{main}{A main title for the plot.}
  \item{xlab}{A label for the x-axis.}
  \item{ylab}{A label for the y-axis.}
  \item{xlim}{The x limits (min,max) of the plot.}
  \item{ylim}{The y limits (min,max) of the plot.}
  \item{lty}{A vector of integers or character strings specifying the
    line type to be used as the default in plotting lines. For further
    information, see \code{\link{par}}.}
  \item{pch}{A vector of integers or single characters specifying
    symbols to be used as the default in plotting points. For further
    information, see \code{\link{par}}.}
  \item{add}{If TRUE, the graph is added to an existing plot.}
  \item{axes}{If FALSE, axes are not drawn around the plot.}
  \item{bty}{A character string which determined the type of box which
    is drawn about plots. For further information, see
    \code{\link{par}}.}
  \item{at}{The points at which tick-marks are to be drawn. For further
    information, see \code{\link{axis}}.}
  \item{touch}{If TRUE, the x-axis and y-axis will touch each other.}
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{lvna}}, \code{\link{plot.response}},
  \code{\link{plot.repeated}}, \code{\link{restovec}},
  \code{\link{rmna}}, \code{\link{tcctomat}}, \code{\link{tvctomat}}.
}
\examples{
library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

par(mfrow=c(2,3))
plot(w,main="All data.")
plot(w,ccov="sex",add=T)
plot(w,ccov="pmi",add=T)
par(mfrow=c(1,1))

rm(w)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

par(mfrow=c(2,2))
plot(w,main="All data.")
plot.new()
plot(w,ccov="distance",add=T)
par(mfrow=c(1,1))

rm(w)
}
\keyword{hplot}

\eof
\name{poprofile}
\title{Produce Predicted Ordinal Time Profiles for Plotting}
\usage{
plot(poprofile(mu,pintercept,preg,pinitial=NULL,depend="independence",
               times=NULL,distribution="multinomial",
               curve.type="probability"),main="Predicted profile",
     xlab=NULL,ylab=NULL,xlim=NULL,ylim=NULL,lty=NULL,add=F,axes=F,
     bty="n",at=NULL,touch=F,...)
}
\alias{poprofile.default}
\alias{plot.poprofile}
\description{
  \code{poprofile} is used for plotting predicted marginal ordinal
  profiles over time for models obtained from dynamic models. These are
  obtained from a function supplied by the user. It produces output for
  plotting highest probabilities and cumulative probabilities for
  predicted marginal ordinal profiles corresponding to a model fitted
  with \code{\link{kalord}}.

  See \code{\link{moprofile}} for plotting marginal ordinal profiles,
  and \code{\link{ioprofile}} for plotting individual ordinal profiles.
}
\arguments{
  \item{mu}{The location regression as a function of the parameters and
    the times for the desired covariate values. The regression function
    must not contain intercepts.}
  \item{pintercept}{Intercept coefficients for the regression model.}
  \item{preg}{Remaining coefficients for the regression model: one for
    each time-constant and time-varying covariate, or one for each
    unknown parameter in their order of appearance.}
  \item{pinitial}{A coefficient for the initial parameter, if it is
    \code{NULL} then this parameter will be fixed at zero.}
  \item{depend}{Type of dependence. Choices are \code{independence}
    (default), \code{Markov}, \code{serial}, and \code{frailty}.}
  \item{times}{Vector of time points at which profiles are to be
    plotted.}
  \item{distribution}{Specifies the parameterization of the logistic
    distribution used in the Pareto distribution. Choices are binary,
    multinomial, continuation-ratio, and proportional-odds.}
  \item{curve.type}{Specifies the type of curves to be plotted. Must
    either be "probability" for highest probabilities or "cumulative"
    for cumulative probabilities.}
  \item{main}{A main title for the plot.}
  \item{xlab}{A label for the x-axis.}
  \item{ylab}{A label for the y-axis.}
  \item{xlim}{The x limits (min,max) of the plot.}
  \item{ylim}{The y limits (min,max) of the plot.}
  \item{lty}{A vector of integers or character strings specifying the
    line type to be used as the default in plotting lines. For further
    information, see \code{\link{par}}.}
  \item{pch}{A vector of integers or single characters specifying
    symbols to be used as the default in plotting points. For further
    information, see \code{\link{par}}.}
  \item{add}{If TRUE, the graph is added to an existing plot.}
  \item{axes}{If FALSE, axes are not drawn around the plot.}
  \item{bty}{A character string which determined the type of box which
    is drawn about plots. For further information, see
    \code{\link{par}}.}
  \item{at}{The points at which tick-marks are to be drawn. For further
    information, see \code{\link{axis}}.}
  \item{touch}{If TRUE, the x-axis and y-axis will touch each other.}
}
\value{
  \code{poprofile} returns information ready for plotting by
  \code{plot.poprofile}.
}
\author{P.J. Lindsey}
\seealso{
  \code{\link{ioprofile}}, \code{\link{kalord}},
  \code{\link{moprofile}}, \code{\link{plot.ordinal}}.
}
\examples{
library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")
ren <- rep(0,4)
cop <- rep(0,4)
dia <- rep(0,4)
sex <- rep(0,4)
pmi <- rep(0,4)
times <- 1:4

# Predicted highest probability profiles.
par(mfrow=c(2,2))
for(i in c(1,25,50,80)) {
  age <- rep(i,4)
  mu <- finterp(attr(z$mu,"formula"),.intercep=F)
  prof <- poprofile(mu,pint=4.43362,preg=c(4.43362,-0.03128,-0.62602,-0.37679,
                                           -0.32969,-0.17013,-0.12209,-0.09095),
                    pinit=NULL,times=times,dist="binary",curve="prob")
  plot(prof,main=paste("Age: ",i,sep=""))
}
par(mfrow=c(1,1))

# Predicted cumulative probability profiles.
par(mfrow=c(2,2))
for(i in c(1,25,50,80)) {
  age <- rep(i,4)
  mu <- finterp(attr(z$mu,"formula"),.intercep=F)
  prof <- poprofile(mu,pint=4.43362,preg=c(-0.03128,-0.62602,-0.37679,-0.32969,
                                           -0.17013,-0.12209,-0.09095),
                    pinit=NULL,times=times,dist="binary",curve="cum")
  plot(prof,main=paste("Age: ",i,sep=""))
}
par(mfrow=c(1,1))

rm(w,z,ren,cop,dia,sex,pmi,times,mu,i,age,prof)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Proportional-odds model with time-constant covariate with a Markov dependence.
z <- kalord(w,distribution="proportional-odds",ccov=~distance,
            preg=c(-1.89,11.652,-0.199),pinit=3.111,pdep=0.217,dep="Markov")

mu <- function(p) rep(p[1]*distance,4)

# Predicted highest probability profiles.
par(mfrow=c(1,2))
for(distance in 1:2)
  plot(poprofile(mu,pint=c(-1.89,11.655),preg=-0.199,pinit=NULL,times=1:4,
                 dist="prop",curve="prob"),main=paste("Distance: ",distance,sep=""))
par(mfrow=c(1,1))

# Predicted cumulative probability profiles.
par(mfrow=c(1,2))
for(distance in 1:2)
  plot(poprofile(mu,pint=c(-1.89,11.655),preg=-0.199,pinit=NULL,times=1:4,
                 dist="prop",curve="cum"),main=paste("Distance: ",distance,sep=""))
par(mfrow=c(1,1))

rm(w,z,mu,distance)
}
\keyword{hplot}

\eof
